@@ -21,9 +21,8 @@ use Exception::Class (%E);
 
 Fey::Exception->Trace(1);
 
-use base 'Exporter';
-
-our @EXPORT_OK = map { $_->{alias} || () } values %E;
+use Sub::Exporter -setup =>
+    { exports => [ map { $_->{alias} || () } values %E ] };
 
 
 1;
@@ -65,7 +64,7 @@ See L<Fey> for details on how to report bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
