@@ -556,7 +556,8 @@ sub SchemaClass
 }
 
 no Moose;
-__PACKAGE__->meta()->make_immutable();
+
+__PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
 
 1;
 
